@@ -2,15 +2,22 @@
 library(pcadapt)
 
 ## ------------------------------------------------------------------------
-data <- read4pcadapt(x="geno3pops",option="example")
-print(dim(data))
+path_to_file <- system.file("extdata","geno3pops",package="pcadapt")
 
-## ------------------------------------------------------------------------
-x <- pcadapt(data,K=20)
+## ----echo=FALSE----------------------------------------------------------
+output.filename <- paste0(path_to_file,20)
+K <- 20
+method = "mahalanobis"
+data.type <- "genotype"
+min.maf <- 0.05
+x <- create.pcadapt(output.filename,K,method,data.type,min.maf)
 
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
 plot(x,option="screeplot")
 
+## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
+plot(x,option="screeplot",K=10)
+
 ## ------------------------------------------------------------------------
 poplist <- c(rep(1,50),rep(2,50),rep(3,50))
 print(poplist)
@@ -21,20 +28,19 @@ plot(x,option="scores",pop=poplist)
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
 plot(x,option="scores",i=3,j=4,pop=poplist)
 
-## ------------------------------------------------------------------------
-x <- pcadapt(data,K=2)
-
-## ------------------------------------------------------------------------
-summary(x)
-
-## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
-plot(x,option="manhattan")
+## ----echo=FALSE----------------------------------------------------------
+output.filename <- path_to_file
+K <- 2
+method = "mahalanobis"
+data.type <- "genotype"
+min.maf <- 0.05
+x <- create.pcadapt(output.filename,K,method,data.type,min.maf)
 
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
 plot(x,option="qqplot",threshold=0.1)
 
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
-hist(x$pvalues,xlab="p-values",main=NULL)
+hist(x$pvalues,xlab="p-values",main=NULL,breaks=50)
 
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
 plot(x,option="stat.distribution")
@@ -49,25 +55,29 @@ outliers <- which(qval<alpha)
 print(outliers)
 
 ## ------------------------------------------------------------------------
-pooldata <- read4pcadapt("pool3pops",option="example",transpose=FALSE)
+pooldata <- system.file("extdata","pool3pops",package="pcadapt")
 
 ## ------------------------------------------------------------------------
-xpool <- pcadapt(pooldata,data.type="pool")
+xpool <- pcadapt(pooldata,data.type="pool",transpose=FALSE)
 
-## ------------------------------------------------------------------------
-x_com <- pcadapt(data,K=2,method="communality")
+## ----echo=FALSE----------------------------------------------------------
+output.filename <- path_to_file
+K <- 2
+method = "communality"
+data.type <- "genotype"
+min.maf <- 0.05
+x_com <- create.pcadapt(output.filename,K,method,data.type,min.maf)
 
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
 plot(x_com,option="stat.distribution")
 
-## ------------------------------------------------------------------------
-x_eucl <- pcadapt(data,K=2,method="euclidean")
-
-## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
-plot(x_eucl,option="stat.distribution")
-
-## ------------------------------------------------------------------------
-x_cw <- pcadapt(data,K=2,method="componentwise")
+## ----echo=FALSE----------------------------------------------------------
+output.filename <- path_to_file
+K <- 2
+method = "componentwise"
+data.type <- "genotype"
+min.maf <- 0.05
+x_cw <- create.pcadapt(output.filename,K,method,data.type,min.maf)
 summary(x_cw$pvalues)
 
 ## ----fig.width=7,fig.height=5,fig.align='center'-------------------------
